# Оглавление  

- [Описание](#description)
- [Установка и запуск](#launch)

<a name="description">

## Описание  

В данной библиотеке реализовано взаимодействие с асинхронной библиотекой RabbitMQ (создание очередей, точек обмена, абстрактный класс для консюмеров сообщений)

<a name="launch">

## Установка и запуск

Перед запуском необходимо установить [Python](https://www.python.org/downloads/release/python-3107/) вместе с pip.

Далее необходимо скачать библиотеку с GitLab:

```
git clone https://gitlab.getstream.ru/getstream/r-n-d/rabbitmq-service-python
```

Открыть из корневой папки проекта командную строку и установить библиотеку в python:

```
python setup.py install
```